# Appendix to the ULB

## Notes About Making a "Relatively Literal" Translation
  * It is not possible to maintain a one-for-one correspondence between words in translation. One word from the source language may require a phrase for its translation in the target language, and vice-versa.
  * It is not possible to translate every word the same way every time it occurs and still have the correct meaning. So the ULB seeks to translate words with the meaning that they have in their context, using whatever English word or phrase is closest to that meaning.
  * Both Greek and Hebrew can make a sentence without using a verb, while English cannot. For the ULB to make sense, the verb will always be supplied. (Usually the verb is "is").
  * Greek makes abundant use of participial clauses. For the English of the ULB to make sense, often these must be changed to relative clauses or adverbial clauses.
  * In the ULB, the grammatical structures of the original languages are retained unless the English would be ungrammatical or easily misunderstood.

## Characteristics of the ULB
The ULB seeks to represent the language forms of the original in a way that also makes sense in English and other Gateway Languages.
  * The ULB tends to reflect the grammatical structures of the biblical languages.
  * The ULB tends to reflectthe parts of speech of the biblical languages. For example, it seeks to use nouns where the original language uses nouns, adjectives where the original language uses adjectives, and so forth.
  * The ULB tneds to reflect the semantically complex vocabulary of the original languages.
  * The ULB seeks to reproduce the form of the logical connections in the biblical languages. Thus, for example, the ULB has "the righteousness of faith" in Romans 4:13, and the logical relationship between righteousness and faith is not further specified. (Is it the righteousness that comes by faith? Is it the righteousness that vindicates faith?) All that "the righteousness of faith" explicitly signals is that there is some close association in the text between righteousness and faith, and that we can probably rule out a number of conceivable logical relationships between the two concepts, but not all possible relationships, as the foregoing example illustrates.
  * The ULB usually reproduces the linear succession of ideas found in the original, even when English may prefer a different arrangement of the same ideas.
  * The ULB does  not normally present information that is only implied in the original. For example, in Matthew 26:5, "For they were saying, 'Not during the festival, so that a riot does not arise among the people.'" The implied information is, "Let us not arrest Jesus [during the festival]." The ULB does not overtly represent this implied information.
  * The ULB reflects as much as reasonably possible the written style of the original. It has, for example, "Paul ... to Timothy..." instead of English's preferred, "Dear Timothy, this is Paul."
  * The ULB departs from closely representing the structures of the original only when it must do so for the sake of clarity in English.
  * Even when the ULB is ambiguous or not entirely clear (as is often true of the original), the ULB must never promote to the translator the wrong meaning.

## Decisions Concerning the ULB
The following are decisions that have been made concerning the ULB. This is not a comprehensive list, but it is here to help those who might wonder why the ULB is as it is.

### ULB Style
The following are details concerning the use of punctuation, capitalization, and vocabulary  in the ULB.

  * Titles are capitalized. (Son of Man, King David, the Messiah).
  * All pronouns, even those referring to God, are lower case (except when beginning sentences and except for the first singular "I").
  * Quotation marks are used at the beginning and ending of direct speech. They are not used at the beginning of each verse, even though the speech may span several verses.
  * Punctuation is normally (not always) inside the quotation marks. 
  * Contractions are not used in the ULB.
  * Where possible, the ULB editors have used common vocabulary that is easy to translate into another language.
  * Numbers are written as words if they have only one or two words ("three hundred," "thirty-five thousand"). Otherwise they are written as numerals. ("205," "1,005")

### Footnotes in the ULB
The ULB has footnotes for the following kinds of issues: 
* names that have multiple spellings
* people and places that have multiple names
* differences in Hebrew and Greek copies that lead to differences in modern versions
* alternative renderings of verses that are very hard to understand in the original languages
* differences between copies of the texts in the original languages and the early Greek and Latin translations

The footnotes use the following words in refering to copies and translations:  
* "Copies" refers to extant copies of the Biblical text, written in the original language, or to copies of the Septuagint or Vulgate.
* "Text" or "original text" refers to the Hebrew or Greek or Aramaic text compiled from all sources (that is, from all extant copies).
* "Translation" refers to ancient translations (the Septuagint and the Vulgate) and to modern translations.
The ULB does not have footnotes for every textual issue, but it does address those that readers are most likely to encounter, particularly readers who have access to translations that were based on manuscripts known before the finding of the Dead Sea scrolls.

## Contributors to the ULB
  - 'Door43 World Missions Community'
  - 'Wycliffe Associates Staff'
  - 'Alrick G. Headley, M.Div., Th.M.'
  - 'Adam W. Nagelvoort, M.Div. Academic Ministries, Columbia International University'
  - 'Dave Statezni, BA Theology-Biblical Literature, M.Div. Biblical Literature and Missions focus'
  - 'Bram van den Heuvel, M.A.'
  - 'C. Harry Harriss, M.Div.'
  - 'David Trombold, M. Div.'
  - 'Elizabeth Oakes, BA in Religious Studies, Linguistics'
  - 'George "Drew" Curley, M.Div., PhD, Professor of Biblical Languages'
  - 'Hendrik "Henry" de Vries'
  - 'Henry Whitney, BA, Education, Translator, Summer Institute of Linguistics 1982-2001'
  - 'Jesse Griffin, BA Biblical Studies, MA Biblical Languages'
  - 'James N. Pohlig, M.Div., MA in Linguistics, D. Litt. in Biblical Languages'
  - 'John Hutchins, BA, Bible and Theology, MA, New Testament, MA, Biblical languages'
  - 'Larry T. Brooks, M.Div., Assemblies of God Theological Seminary'
  - 'Larry Sallee, D.Min.' 
  - 'Paul M Fahnestock, M.Div. Reformed Theological Seminary, D. Min. Pittsburgh Theological Seminary'
  - 'Perry Oakes, PhD in Old Testament, MA in Linguistics'
  - 'Peter Smircich, BA Philosophy'
  - 'Robert W. Johnson, B.S./M.S., Chemical Engineering'
  - 'Susan R. Quigley, MA in Linguistics'
  - 'W. Thomas Warren, BA (Bible), M.Div., D.Min'
  - 'Timothy Neu, Ph.D. Biblical Studies'
  - 'Ward Pyles, M.Div., Western Baptist Theological Seminary'
  - 'David Trombold'
  - 'Dean Ropp'
  - 'Gene Mullen'
  - 'James Vigen'
  - 'Leonard Smith'
  - 'Nicholas Alsop'
  - 'Michael Francis'


